"""
Keep track of supported languages, affecting both the UI and the Makefile.
The Makefile parses this file to generate the language files.
"""


def supported_languages() -> dict[str, tuple[str, bool]]:
    """
    Return a dictionary of supported languages.
    language code -> (language name, enabled)
    A disabled language won't show up in the UI, but the language file will still be generated.

    :return: Supported languages
    """
    return {
        "en_US": ("English (US)", True),  # Default language, locale C
        "de_DE": ("Deutsch (DE)", True),
        "es_ES": ("Spanish (ES)", False),
        "fr_FR": ("French (FR)", False),
        "tr_TR": ("Turkish (TR)", False),
    }



from datetime import datetime
from typing import Sequence

import PySide6.QtCore as Qc
import PySide6.QtGui as Qg
import PySide6.QtWidgets as Qw
from loguru import logger

import pcleaner.gui.log_parser as lp
import pcleaner.cli_utils as cu
import pcleaner.helpers as hp
from pcleaner.gui.ui_generated_files.ui_IssueReporter import Ui_IssueReporter


class IssueReporter(Qw.QDialog, Ui_IssueReporter):
    """
    Show logs of individual sessions and allow the user to report an issue.
    """

    sessions: Sequence[lp.LogSession]

    def __init__(
        self,
        parent=None,
    ) -> None:
        """
        Init the widget.

        :param parent: The parent widget.
        """
        Qw.QDialog.__init__(self, parent)
        self.setupUi(self)

        self.pushButton_close.clicked.connect(self.close)
        self.pushButton_open_issues.clicked.connect(self.open_issues)
        self.pushButton_clipboard.clicked.connect(self.copy_to_clipboard)

        self.load_logs()
        # Only connect the signal after the logs are loaded to not double-trigger
        # the update when making the initial selection.
        self.comboBox_sessions.currentIndexChanged.connect(self.show_log)
        self.show_log()

        self.label_log_path.setText(str(cu.get_log_path()))
        self.label_name_hidden.setText(
            self.tr("Note: Name {name} was hidden").format(name=lp.get_username())
        )

    def load_logs(self) -> None:
        """
        Load the logs.
        """

        log_text = lp.load_log_file()
        if log_text is None:
            return

        self.sessions = lp.parse_log_file(log_text)

        for index, session in enumerate(self.sessions):
            text: str
            if session.corrupted:
                text = self.tr("Corrupted log session")
            elif index == 0:
                text = self.tr("Current session")
            else:
                today = datetime.now().date()
                if session.date_time.date() == today:
                    text = self.tr("Today") + session.date_time.strftime(" %H:%M:%S")
                else:
                    text = session.date_time.strftime("%Y-%m-%d %H:%M:%S")

            text += " – "
            text += f"{session.errors} " + hp.f_plural(
                session.errors, self.tr("Error"), self.tr("Errors")
            )
            if session.criticals:
                text += f", {session.criticals} " + hp.f_plural(
                    session.criticals, self.tr("Critical"), self.tr("Criticals")
                )

            self.comboBox_sessions.addTextItemLinkedData(text, index)

    def show_log(self) -> None:
        """
        Show the log in the text edit.
        """

        session_index = self.comboBox_sessions.currentLinkedData()

        session = self.sessions[session_index]
        self.log_viewer.show_log(session.text)

    @staticmethod
    def open_issues() -> None:
        """
        Open the issues page in the browser.
        """
        logger.debug("Opening github issues page.")
        Qg.QDesktopServices.openUrl(Qc.QUrl("https://github.com/VoxelCubes/PanelCleaner/issues"))

    def copy_to_clipboard(self) -> None:
        """
        Copy the issue report to the clipboard.
        """
        logger.debug("Copying issue report to clipboard.")
        text = self.log_viewer.get_log()
        Qg.QGuiApplication.clipboard().setText(text)



import re
import os
from datetime import datetime
from typing import Sequence

import pcleaner.config as cfg
import pcleaner.cli_utils as cu

MAX_SESSIONS = 30


def get_username() -> str:
    """
    Get the username of the current user.
    We want to censor this in the log files for privacy.

    :return: The username of the current user.
    """
    return os.getlogin()


def censor(text: str) -> str:
    """
    Censor the username from the log file.
    We want to censor this in the log files for privacy.

    :param text: The text to censor.
    :return: The censored text.
    """
    return text.replace(get_username(), "<username>")


class LogSession:
    text: str
    date_time: datetime
    errors: int
    criticals: int
    corrupted: bool

    def __init__(self, text: str) -> None:
        self.text = text
        self.date_time = datetime.now()
        self.errors = 0
        self.criticals = 0
        self.corrupted = False
        self.parse()
        self.censor()

    def parse(self) -> None:
        self.errors = self.text.count("ERROR")
        self.criticals = self.text.count("CRITICAL")
        # Find the first parsable date in the log session.
        # Example: 2024-01-27 22:51:03.778
        first_date = re.search(r"\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}", self.text)
        if first_date:
            self.date_time = datetime.strptime(first_date.group(), "%Y-%m-%d %H:%M:%S")
        else:
            # If no date is found, we assume the log session is corrupted, since every
            # log session should start with a date.
            self.corrupted = True

    def censor(self) -> None:
        self.text = censor(self.text)


def load_log_file() -> str | None:
    """
    Load the log file. If none exists, return None.
    None existing is a bit odd, but it is possible that the log file was deleted.
    Not a big deal, but it is something to consider.

    :return: The log file contents.
    """
    contents = None
    try:
        with open(cu.get_log_path(), "r", encoding="utf-8") as file:
            contents = file.read()
    except FileNotFoundError:
        pass
    return contents


def parse_log_file(contents: str, max_sessions: int = MAX_SESSIONS) -> Sequence[LogSession]:
    """
    Parse the log file contents.

    :param contents: The log file contents.
    :param max_sessions: The maximum number of sessions to parse.
    :return: A list of log sessions, sorted by date, newest first.
    """

    sessions = []
    # Split the log file into sections based on start and shutdown messages
    raw_sessions = re.split(rf"({cfg.STARTUP_MESSAGE})", contents)

    # Pairing each startup message with its corresponding log session
    for i in range(len(raw_sessions) - 2, 0, -2):
        if raw_sessions[i] == cfg.STARTUP_MESSAGE and i + 1 < len(raw_sessions):
            session_text = raw_sessions[i + 1]
            # If there is a shutdown message, find it and truncate the session text
            shutdown_index = session_text.find(cfg.SHUTDOWN_MESSAGE, -500)
            if shutdown_index != -1:
                shutdown_index = session_text.find("\n", shutdown_index)
                if shutdown_index != -1:
                    session_text = session_text[:shutdown_index]

            session_text = session_text.strip()

            # Append sessions in reverse order
            sessions.append(LogSession(session_text))

            # Stop if the maximum number of sessions is reached
            if len(sessions) >= max_sessions:
                break

    return sessions



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'SetupGreeter.ui'
##
## Created by: Qt User Interface Compiler version 6.6.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QDialog, QFormLayout, QHBoxLayout,
    QLabel, QPushButton, QSizePolicy, QSpacerItem,
    QVBoxLayout, QWidget)

class Ui_SetupGreeter(object):
    def setupUi(self, SetupGreeter):
        if not SetupGreeter.objectName():
            SetupGreeter.setObjectName(u"SetupGreeter")
        SetupGreeter.resize(720, 490)
        SetupGreeter.setMinimumSize(QSize(600, 0))
        SetupGreeter.setModal(True)
        self.verticalLayout = QVBoxLayout(SetupGreeter)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(-1, 20, -1, -1)
        self.label_2 = QLabel(SetupGreeter)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setTextFormat(Qt.MarkdownText)

        self.verticalLayout.addWidget(self.label_2, 0, Qt.AlignHCenter)

        self.verticalSpacer_4 = QSpacerItem(20, 14, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Fixed)

        self.verticalLayout.addItem(self.verticalSpacer_4)

        self.label = QLabel(SetupGreeter)
        self.label.setObjectName(u"label")
        self.label.setTextFormat(Qt.MarkdownText)
        self.label.setWordWrap(True)
        self.label.setOpenExternalLinks(True)
        self.label.setTextInteractionFlags(Qt.NoTextInteraction)

        self.verticalLayout.addWidget(self.label)

        self.verticalSpacer_5 = QSpacerItem(20, 14, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Fixed)

        self.verticalLayout.addItem(self.verticalSpacer_5)

        self.formLayout = QFormLayout()
        self.formLayout.setObjectName(u"formLayout")
        self.formLayout.setFieldGrowthPolicy(QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setRowWrapPolicy(QFormLayout.WrapLongRows)
        self.formLayout.setHorizontalSpacing(6)
        self.formLayout.setVerticalSpacing(6)
        self.label_9 = QLabel(SetupGreeter)
        self.label_9.setObjectName(u"label_9")

        self.formLayout.setWidget(0, QFormLayout.LabelRole, self.label_9)

        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.label_6 = QLabel(SetupGreeter)
        self.label_6.setObjectName(u"label_6")
        sizePolicy = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_6.sizePolicy().hasHeightForWidth())
        self.label_6.setSizePolicy(sizePolicy)
        self.label_6.setText(u"[https://github.com/zyddnys/manga-image-translator/releases](https://github.com/zyddnys/manga-image-translator/releases)")
        self.label_6.setTextFormat(Qt.MarkdownText)
        self.label_6.setWordWrap(True)
        self.label_6.setOpenExternalLinks(True)
        self.label_6.setTextInteractionFlags(Qt.TextBrowserInteraction)

        self.verticalLayout_2.addWidget(self.label_6)

        self.label_11 = QLabel(SetupGreeter)
        self.label_11.setObjectName(u"label_11")
        sizePolicy.setHeightForWidth(self.label_11.sizePolicy().hasHeightForWidth())
        self.label_11.setSizePolicy(sizePolicy)
        self.label_11.setTextFormat(Qt.MarkdownText)
        self.label_11.setWordWrap(True)
        self.label_11.setOpenExternalLinks(True)
        self.label_11.setTextInteractionFlags(Qt.TextBrowserInteraction)

        self.verticalLayout_2.addWidget(self.label_11)


        self.formLayout.setLayout(0, QFormLayout.FieldRole, self.verticalLayout_2)

        self.label_4 = QLabel(SetupGreeter)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setTextFormat(Qt.PlainText)
        self.label_4.setWordWrap(True)
        self.label_4.setOpenExternalLinks(True)
        self.label_4.setTextInteractionFlags(Qt.NoTextInteraction)

        self.formLayout.setWidget(1, QFormLayout.LabelRole, self.label_4)

        self.label_text_detector_path = QLabel(SetupGreeter)
        self.label_text_detector_path.setObjectName(u"label_text_detector_path")
        sizePolicy1 = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Preferred)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.label_text_detector_path.sizePolicy().hasHeightForWidth())
        self.label_text_detector_path.setSizePolicy(sizePolicy1)
        self.label_text_detector_path.setText(u"<text detection path>")
        self.label_text_detector_path.setWordWrap(True)
        self.label_text_detector_path.setTextInteractionFlags(Qt.TextSelectableByKeyboard|Qt.TextSelectableByMouse)

        self.formLayout.setWidget(1, QFormLayout.FieldRole, self.label_text_detector_path)

        self.verticalSpacer_2 = QSpacerItem(20, 10, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Maximum)

        self.formLayout.setItem(2, QFormLayout.LabelRole, self.verticalSpacer_2)

        self.label_10 = QLabel(SetupGreeter)
        self.label_10.setObjectName(u"label_10")
        self.label_10.setWordWrap(True)

        self.formLayout.setWidget(3, QFormLayout.LabelRole, self.label_10)

        self.label_5 = QLabel(SetupGreeter)
        self.label_5.setObjectName(u"label_5")
        sizePolicy1.setHeightForWidth(self.label_5.sizePolicy().hasHeightForWidth())
        self.label_5.setSizePolicy(sizePolicy1)
        self.label_5.setText(u"[https://huggingface.co/kha-white/manga-ocr-base/tree/main](https://huggingface.co/kha-white/manga-ocr-base/tree/main)")
        self.label_5.setTextFormat(Qt.MarkdownText)
        self.label_5.setWordWrap(True)
        self.label_5.setOpenExternalLinks(True)
        self.label_5.setTextInteractionFlags(Qt.TextBrowserInteraction)

        self.formLayout.setWidget(3, QFormLayout.FieldRole, self.label_5)

        self.label_7 = QLabel(SetupGreeter)
        self.label_7.setObjectName(u"label_7")
        self.label_7.setTextFormat(Qt.PlainText)
        self.label_7.setWordWrap(True)
        self.label_7.setOpenExternalLinks(True)
        self.label_7.setTextInteractionFlags(Qt.NoTextInteraction)

        self.formLayout.setWidget(4, QFormLayout.LabelRole, self.label_7)

        self.label_ocr_path = QLabel(SetupGreeter)
        self.label_ocr_path.setObjectName(u"label_ocr_path")
        sizePolicy1.setHeightForWidth(self.label_ocr_path.sizePolicy().hasHeightForWidth())
        self.label_ocr_path.setSizePolicy(sizePolicy1)
        self.label_ocr_path.setText(u"<ocr path>")
        self.label_ocr_path.setWordWrap(True)
        self.label_ocr_path.setTextInteractionFlags(Qt.TextSelectableByKeyboard|Qt.TextSelectableByMouse)

        self.formLayout.setWidget(4, QFormLayout.FieldRole, self.label_ocr_path)

        self.label_12 = QLabel(SetupGreeter)
        self.label_12.setObjectName(u"label_12")
        self.label_12.setWordWrap(True)

        self.formLayout.setWidget(6, QFormLayout.LabelRole, self.label_12)

        self.label_13 = QLabel(SetupGreeter)
        self.label_13.setObjectName(u"label_13")
        sizePolicy1.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy1)
        self.label_13.setText(u"[https://github.com/enesmsahin/simple-lama-inpainting/releases](https://github.com/enesmsahin/simple-lama-inpainting/releases)")
        self.label_13.setTextFormat(Qt.MarkdownText)
        self.label_13.setWordWrap(True)
        self.label_13.setOpenExternalLinks(True)
        self.label_13.setTextInteractionFlags(Qt.TextBrowserInteraction)

        self.formLayout.setWidget(6, QFormLayout.FieldRole, self.label_13)

        self.label_8 = QLabel(SetupGreeter)
        self.label_8.setObjectName(u"label_8")
        self.label_8.setTextFormat(Qt.PlainText)
        self.label_8.setWordWrap(True)
        self.label_8.setOpenExternalLinks(True)
        self.label_8.setTextInteractionFlags(Qt.NoTextInteraction)

        self.formLayout.setWidget(7, QFormLayout.LabelRole, self.label_8)

        self.label_inpainting_path = QLabel(SetupGreeter)
        self.label_inpainting_path.setObjectName(u"label_inpainting_path")
        sizePolicy1.setHeightForWidth(self.label_inpainting_path.sizePolicy().hasHeightForWidth())
        self.label_inpainting_path.setSizePolicy(sizePolicy1)
        self.label_inpainting_path.setText(u"<inpainting path>")
        self.label_inpainting_path.setWordWrap(True)
        self.label_inpainting_path.setTextInteractionFlags(Qt.TextSelectableByKeyboard|Qt.TextSelectableByMouse)

        self.formLayout.setWidget(7, QFormLayout.FieldRole, self.label_inpainting_path)

        self.verticalSpacer_3 = QSpacerItem(20, 10, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Maximum)

        self.formLayout.setItem(5, QFormLayout.LabelRole, self.verticalSpacer_3)


        self.verticalLayout.addLayout(self.formLayout)

        self.verticalSpacer = QSpacerItem(0, 0, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout.addItem(self.verticalSpacer)

        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer)

        self.pushButton_ok = QPushButton(SetupGreeter)
        self.pushButton_ok.setObjectName(u"pushButton_ok")
        icon = QIcon(QIcon.fromTheme(u"download"))
        self.pushButton_ok.setIcon(icon)
        self.pushButton_ok.setAutoDefault(True)

        self.horizontalLayout.addWidget(self.pushButton_ok)

        self.pushButton_abort = QPushButton(SetupGreeter)
        self.pushButton_abort.setObjectName(u"pushButton_abort")
        icon1 = QIcon(QIcon.fromTheme(u"dialog-cancel"))
        self.pushButton_abort.setIcon(icon1)

        self.horizontalLayout.addWidget(self.pushButton_abort)


        self.verticalLayout.addLayout(self.horizontalLayout)


        self.retranslateUi(SetupGreeter)
        self.pushButton_ok.clicked.connect(SetupGreeter.accept)
        self.pushButton_abort.clicked.connect(SetupGreeter.reject)

        self.pushButton_ok.setDefault(False)


        QMetaObject.connectSlotsByName(SetupGreeter)
    # setupUi

    def retranslateUi(self, SetupGreeter):
        SetupGreeter.setWindowTitle(QCoreApplication.translate("SetupGreeter", u"Downloading Machine Learning Models", None))
        self.label_2.setText(QCoreApplication.translate("SetupGreeter", u"## Setting up Panel Cleaner", None))
        self.label.setText(QCoreApplication.translate("SetupGreeter", u"Before Panel Cleaner can begin, it requires the following machine learning models. Press **Automatically Download** to allow Panel Cleaner to download these files to get started (Internet connection required, total space approx. 700 MiB)", None))
        self.label_9.setText(QCoreApplication.translate("SetupGreeter", u"Text Detection:", None))
        self.label_11.setText(QCoreApplication.translate("SetupGreeter", u"(only the comictextdetector file is needed)", None))
        self.label_4.setText(QCoreApplication.translate("SetupGreeter", u"Saved in:", None))
        self.label_10.setText(QCoreApplication.translate("SetupGreeter", u"Optical Character Recognition (OCR):", None))
        self.label_7.setText(QCoreApplication.translate("SetupGreeter", u"Saved in:", None))
        self.label_12.setText(QCoreApplication.translate("SetupGreeter", u"Inpainting:", None))
        self.label_8.setText(QCoreApplication.translate("SetupGreeter", u"Saved in:", None))
        self.pushButton_ok.setText(QCoreApplication.translate("SetupGreeter", u"Automatically Download", None))
        self.pushButton_abort.setText(QCoreApplication.translate("SetupGreeter", u"Abort", None))
    # retranslateUi




import os
import platform
import sys
from io import StringIO

import PySide6
import PySide6.QtGui as Qg
import PySide6.QtWidgets as Qw
import PySide6.QtCore as Qc
from loguru import logger
import torch
from docopt import docopt

import pcleaner.cli_utils as cu
import pcleaner.config as cfg
from pcleaner import __display_name__, __version__
from pcleaner.gui.mainwindow_driver import MainWindow


# This import is needed to load the icons.
import pcleaner.gui.rc_generated_files.rc_icons
import pcleaner.gui.rc_generated_files.rc_theme_icons
import pcleaner.gui.rc_generated_files.rc_themes
import pcleaner.gui.rc_generated_files.rc_translations


def launch(files_to_open: list[str], debug: bool = False) -> None:
    """
    Launch the GUI.

    :param files_to_open: A list of files to open.
    :param debug: Whether to enable debug mode.
    """

    cu.get_log_path().parent.mkdir(parents=True, exist_ok=True)
    # Log up to 1MB to the log file.
    # loguru.logfile(str(cu.get_log_path()), maxBytes=2**30, backupCount=1, loglevel=loguru.DEBUG)

    # Set up file logging.
    logger.add(str(cu.get_log_path()), rotation="10 MB", retention="1 week", level="DEBUG")

    logger.info("\n" + cfg.STARTUP_MESSAGE)
    buffer = StringIO()
    buffer.write("\n- Program Information -\n")
    buffer.write(f"Program: {__display_name__} {__version__}\n")
    buffer.write(f"Executing from: {__file__}\n")
    buffer.write(f"Log file: {cu.get_log_path()}\n")
    buffer.write(f"Config file: {cu.get_config_path()}\n")
    buffer.write(f"Cache directory: {cu.get_cache_path()}\n")
    buffer.write("- System Information -\n")
    buffer.write(f"Operating System: {platform.system()} {platform.release()}\n")
    if platform.system() == "Linux":
        buffer.write(f"Desktop Environment: {os.getenv('XDG_CURRENT_DESKTOP', 'unknown')}\n")
    buffer.write(f"Machine: {platform.machine()}\n")
    buffer.write(f"Python Version: {sys.version}\n")
    buffer.write(f"PySide (Qt) Version: {PySide6.__version__}\n")
    buffer.write(f"Available Qt Themes: {', '.join(Qw.QStyleFactory.keys())}\n")
    buffer.write(f"System locale: {Qc.QLocale.system().name()}\n")
    buffer.write(f"CPU Cores: {os.cpu_count()}\n")
    if torch.cuda.is_available():
        buffer.write(f"GPU: {torch.cuda.get_device_name(0)} (CUDA enabled)\n")
    else:
        buffer.write("GPU: None (CUDA not available)\n")

    logger.info(buffer.getvalue())

    # Start the main window.
    app = Qw.QApplication(sys.argv)

    # Load the config.
    config = cfg.load_config()

    # Apply the locale from the config.
    if config.locale:
        locale = Qc.QLocale(config.locale)
    else:
        locale = Qc.QLocale.system()

    logger.info(f"Using locale {locale.name()}.")

    translator = Qc.QTranslator(app)

    # Load translations.
    path = Qc.QLibraryInfo.location(Qc.QLibraryInfo.TranslationsPath)
    if translator.load(locale, "qt", "_", path):
        logger.debug(f"Loaded built-in Qt translations for {locale.name()}.")
        app.installTranslator(translator)
    else:
        logger.warning(f"Failed to load Qt translations from {path}.")

    translator = Qc.QTranslator(app)

    if translator.load(locale, "qtbase", "_", path):
        logger.debug(f"Loaded built-in Qt base translations for {locale.name()}.")
        app.installTranslator(translator)
    else:
        logger.warning(f"Failed to load Qt base translations from {path}.")

    translator = Qc.QTranslator(app)

    path = ":/translations"
    if translator.load(locale, "PanelCleaner", "_", path):
        app.installTranslator(translator)
        logger.debug(f"Loaded App translations for {locale.name()}.")

    Qg.QIcon.setFallbackSearchPaths([":/icons", ":/icon-themes"])
    # We need to set an initial theme on Windows, otherwise the icons will fail to load
    # later on, even when switching the theme again.
    if platform.system() == "Windows":
        Qg.QIcon.setThemeName("breeze")
        Qg.QIcon.setThemeSearchPaths([":/icons", ":/icon-themes"])

    if files_to_open:
        input_paths = ", ".join(map(str, files_to_open))
        logger.info(f"Files to open: {input_paths}")

    try:
        window = MainWindow(config, files_to_open, debug)
        window.show()
        sys.exit(app.exec())
    except Exception:
        logger.opt(exception=True).critical("Failed to initialize the main window.")
    finally:
        logger.info(cfg.SHUTDOWN_MESSAGE + "\n")


def main():
    docopt_doc = """Panel Cleaner

    Usage:
        pcleaner-gui [<image_path> ...] [--debug]

    Options:
        <image_path>          One or multiple files or directories to clean.
                              Leave blank to use the current working directory.
        --debug               Enable debug mode.
    """
    args = docopt(docopt_doc, version=f"Panel Cleaner {__version__}")
    launch(args.image_path, args.debug)


if __name__ == "__main__":
    main()
